OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Η έκδοση {version} είναι διαθέσιμη. Δείτε περισσότερες πληροφορίες για το πως να κάνετε την ενημέρωση.",
    "Channel updated" : "Ενημερωμένο κανάλι",
    "Update notifications" : "Ειδοποιήσεις ενημέρωσης",
    "The update server could not be reached since %d days to check for new updates." : "Ο διακομιστής ενημέρωσης δεν ήταν προσβάσιμος από %dημέρες για να ελέγξει για νέες ενημερώσεις. ",
    "Please check the Nextcloud and server log files for errors." : "Παρακαλούμε ελέγξτε για σφάλματα στα αρχεία ιστορικού του Nextcloud και του διακομιστή σας.",
    "Update to %1$s is available." : "Είναι διαθέσιμη η ενημέρωση σε %1$s.",
    "Update for %1$s to version %2$s is available." : "Είναι διαθέσιμη η ενημέρωση από την έκδοση %1$s στην %2$s.",
    "Update for {app} to version %s is available." : "Είναι διαθέσιμη η ενημέρωση της εφαρμογής {app} στην έκδοση %s",
    "Update notification" : "Ειδοποίηση ενημέρωσης",
    "View in store" : "Προβολή στο κέντρο εφαρμογών",
    "Apps with available updates" : "Εφαρμογές με διαθέσιμες ενημερώσεις",
    "Open updater" : "Άνοιγμα εφαρμογής ενημέρωσης",
    "Download now" : "Λήψη τώρα",
    "What's new?" : "Τι νέο υπάρχει;",
    "Your version is up to date." : "Έχετε την τελευταία έκδοση.",
    "Update channel:" : "Ενημέρωση καναλιού:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Μπορείτε πάντα να ενημερώσετε σε μια νεότερη έκδοση. Αλλά δεν μπορείτε ποτέ να υποβαθμίσετε σε μια πιο σταθερή έκδοση.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Σημειώστε ότι μετά από μια νέα διανομή μπορεί να περάσει λίγος καιρός πριν εμφανιστεί εδώ. Κυκλοφορούμε κατά διαστήματα νέες εκδόσεις στους χρήστες μας και κάποιες φορές παραλείπουμε κάποια έκδοση αν βρεθούν προβλήματα.",
    "Notify members of the following groups about available updates:" : "Να ενημερωθούν τα μέλη των παρακάτω ομάδων σχετικά με τις διαθέσιμες ενημερώσεις:",
    "Only notification for app updates are available." : "Είναι μόνο διαθέσιμες οι ενημερώσεις για την εφαρμογή",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Το συγκεκριμένο κανάλι ενημέρωσης καθιστά παρωχημένες τις ειδοποιήσεις που προορίζονται για τον διακομιστή.",
    "The selected update channel does not support updates of the server." : "Το συγκεκριμένο κανάλι ενημέρωσης δεν υποστηρίζει ενημερώσεις διακομιστή.",
    "Checking apps for compatible updates" : "Έλεγχος εφαρμογών για συμβατές ενημερώσεις",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Αδυναμία σύνδεσης στο κατάστημα εφαρμογών, ή το κατάστημα εφαρμογών δεν εξέδωσε καμία ενημέρωση. Αναζητήστε χειροκίνητα ενημερώσεις ή βεβαιωθείτε ότι ο εξυπηρετητής έχει πρόσβαση στο διαδίκτυο και μπορεί να συνδεθεί στο κατάστημα εφαρμογών. ",
    "View changelog" : "Εμφάνιση αλλαγών",
    "Stable" : "Σταθερός",
    "A pre-release version only for testing new features, not for production environments." : "Μια προηγούμενη έκδοση μόνο για τη δοκιμή νέων λειτουργιών, όχι για περιβάλλοντα παραγωγής.",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Μπορείτε πάντα να περάσετε σε νεότερη / πειραματική έκδοση. Αλλά ποτέ δεν μπορείτε να γυρίσετε πίσω σε πιο σταθερό κανάλι."
},
"nplurals=2; plural=(n != 1);");
